.. _guide:

===============
 User Guide
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    application
    agents
    streams
    channels
    models
    tables
    tasks
    cli
    sensors
    testing
    livecheck
    settings
    installation
    kafka
    debugging
    workers
